/*
 * Copyright 1992 by Frank Adelstein.  All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose is hereby granted without fee, provided that
 * the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the authors name not be used in advertising or
 * publicity pertaining to distribution of the software without specific,
 * written prior permission.  The author makes no representations about the
 * suitability of this software for any purpose.  It is provided "as is"
 * without express or implied warranty.
 *
 * THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
 * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS,
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, INDIRECT
 * OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
 * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
 * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */


/************/
/* INCLUDES */
/************/

#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>
#include <X11/Shell.h>

#include <X11/Xaw/AsciiText.h>
#include <X11/Xaw/Command.h>
#include <X11/Xaw/Form.h>
#include <X11/Xaw/Label.h>
#include <X11/Xaw/Scrollbar.h>
#include <X11/Xaw/Toggle.h>
#include <X11/Xaw/Viewport.h>

#include <X11/cursorfont.h>
#define XK_MISCELLANY  1
#define XK_LATIN1  1
#include <X11/keysymdef.h>

#include <stdio.h>
#include <errno.h>
#include <math.h>
#include <signal.h>

/*************/
/* DEFINES   */
/*************/

#define TITLE     "xlax"
#define CLASS     "Xlax"
#define MAXEVENTS 150

/*************/
/* types     */
/*************/

typedef struct {
  Window wind;
  int    active;
  XKeyEvent events[MAXEVENTS];
  int    eventindex;
  Widget button;
  Widget text;
} Windows_t;

/*************/
/* GLOBALS   */
/*************/

void SetupInterface();
void selectCB();
void findCB();
void killCB();
void keyboardCB();
void toggleCB();
void quitCB();
void senditCB();
void togglestringCB();
void stringinputCB();
void okCB();
void clearCB();
void cancelCB();
void Find_Xlax();
void Add_Window();
void presetString();
KeyCode CharToKeycodeMod();

int ksym[256]={
-1, XK_A, XK_B, XK_C, XK_D, XK_E, XK_F, XK_G, XK_H, XK_Tab, XK_Linefeed,
XK_Clear, XK_L, XK_Return, XK_N, XK_O, XK_P, XK_Q, XK_R, XK_S, XK_T,
XK_U, XK_V, XK_W, XK_X, XK_Y, XK_Z,
XK_Escape, XK_bracketleft, XK_backslash, XK_bracketright, XK_asciicircum,

XK_space, XK_exclam, XK_quotedbl, XK_numbersign, XK_dollar, XK_percent,
XK_ampersand, XK_apostrophe, XK_parenleft, XK_parenright, XK_asterisk,
XK_plus, XK_comma, XK_minus, XK_period, XK_slash,
XK_0, XK_1, XK_2, XK_3, XK_4, XK_5, XK_6, XK_7, XK_8, XK_9,
XK_colon, XK_semicolon, XK_less, XK_equal, XK_greater, XK_question,

XK_at, XK_A, XK_B, XK_C, XK_D, XK_E, XK_F, XK_G, XK_H, XK_I, XK_J,
XK_K, XK_L, XK_M, XK_N, XK_O, XK_P, XK_Q, XK_R, XK_S, XK_T,
XK_U, XK_V, XK_W, XK_X, XK_Y, XK_Z,
XK_bracketleft, XK_backslash, XK_bracketright, XK_asciicircum, XK_underscore,

XK_grave, XK_a, XK_b, XK_c, XK_d, XK_e, XK_f, XK_g, XK_h, XK_i, XK_j,
XK_k, XK_l, XK_m, XK_n, XK_o, XK_p, XK_q, XK_r, XK_s, XK_t,
XK_u, XK_v, XK_w, XK_x, XK_y, XK_z,
XK_braceleft, XK_bar, XK_braceright, XK_asciitilde, XK_Delete
};

int mod[256]={
0, 4, 4, 4, 4, 4, 4, 4, 4, 0, 0,
0, 4, 0, 4, 4, 4, 4, 4, 4, 4,
4, 4, 4, 4, 4, 4,
0, 4, 4, 5, 5,

0, 1, 1, 1, 1, 1,
1, 0, 1, 1, 1,
1, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
1, 0, 1, 0, 1, 1,

1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
1, 1, 1, 1, 1, 1,
0, 0, 0, 1, 1,

1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
0, 0, 0, 0, 0, 0,
1, 1, 1, 1, 0,
};

